==> open-xchange-core_7.8.1.orig.tar.bz2: open-xchange-core-7.8.1/com.openexchange.server/src/com/openexchange/groupware/update/Updater.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.update;

import java.util.Collection;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.contexts.Context;
import com.openexchange.groupware.update.internal.UpdaterImpl;

/**
 * Interface for the updater.
 * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
 */
public abstract class Updater {

    /**
     * Default constructor.
     */
    protected Updater() {
        super();
    }

    /**
     * Factory method to get an updater.
     * @return the updater.
     * @throws OXException if instantiating the implementation fails.
     */
    public static Updater getInstance() {
        return new UpdaterImpl();
    }

    public final UpdateStatus getStatus(final Context ctx) throws OXException {
        return getStatus(ctx.getContextId());
    }

    public abstract UpdateStatus getStatus(int contextId) throws OXException;

    public abstract UpdateStatus getStatus(String schema, int writePoolId) throws OXException;

    /**
     * Starts the update process on a schema.
     * @param contextId Context inside the schema.
     * @throws OXException if an exception occurs.
     */
    public final void startUpdate(final Context ctx) throws OXException {
        startUpdate(ctx.getContextId());
    }

    /**
     * Starts the update process on a schema.
     * @param contextId Identifier of a context inside the schema.
     * @throws OXException if an exception occurs.
     */
    public abstract void startUpdate(int contextId) throws OXException;

    public abstract UpdateTaskV2[] getAvailableUpdateTasks();

    /**
     * Gets a list of schemas whose update tasks have been scheduled for execution
     * or are currently running on this node.
     *
     * @return The list of schemas
     */
    public abstract Collection<String> getLocallyScheduledTasks();
}

==> open-xchange-core_7.10.0.orig.tar.bz2: open-xchange-core-7.10.0/com.openexchange.server/src/com/openexchange/groupware/update/Updater.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.update;

import java.util.Collection;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.contexts.Context;
import com.openexchange.groupware.update.internal.UpdaterImpl;

/**
 * Interface for the updater.
 * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
 */
public abstract class Updater {

    /**
     * Factory method to get an updater.
     *
     * @return the updater.
     * @throws OXException if instantiating the implementation fails.
     */
    public static Updater getInstance() {
        return UpdaterImpl.getInstance();
    }

    // -----------------------------------------------------------------------------------------------------------------------------

    /**
     * Default constructor.
     */
    protected Updater() {
        super();
    }

    public final UpdateStatus getStatus(final Context ctx) throws OXException {
        return getStatus(ctx.getContextId());
    }

    public abstract UpdateStatus getStatus(int contextId) throws OXException;

    public abstract UpdateStatus getStatus(String schema, int writePoolId) throws OXException;

    /**
     * Unblocks specified schema (if updating for too long)
     *
     * @param schemaName The schema name
     * @param poolId The pool identifier
     * @param contextId The context identifier
     * @throws OXException If unblocking fails
     */
    public abstract void unblock(String schemaName, int poolId, int contextId) throws OXException;

    /**
     * Starts the update process on a schema.
     * @param contextId Context inside the schema.
     * @throws OXException if an exception occurs.
     */
    public final void startUpdate(final Context ctx) throws OXException {
        startUpdate(ctx.getContextId());
    }

    /**
     * Starts the update process on a schema.
     * @param contextId Identifier of a context inside the schema.
     * @throws OXException if an exception occurs.
     */
    public abstract void startUpdate(int contextId) throws OXException;

    public abstract UpdateTaskV2[] getAvailableUpdateTasks();

    /**
     * Gets a list of schemas whose update tasks have been scheduled for execution
     * or are currently running on this node.
     *
     * @return The list of schemas
     */
    public abstract Collection<String> getLocallyScheduledTasks();
}
